@@ -27,21 +27,18 @@
 #include <gdk/gdk.h>
 #include <config.h> // For definition of ENABLE_OGG, ...
 
-
-/***************
- * Declaration *
- ***************/
+G_BEGIN_DECLS
 
 /*
  * Colors Used (see declaration into et_core.c)
  */
-GdkColor LIGHT_BLUE;
-GdkColor RED;
-GdkColor LIGHT_RED;
-GdkColor GREY;
-GdkColor LIGHT_GREY;
-GdkColor YELLOW;
-GdkColor BLACK;
+extern GdkColor LIGHT_BLUE;
+extern GdkColor RED;
+extern GdkColor LIGHT_RED;
+extern GdkColor GREY;
+extern GdkColor LIGHT_GREY;
+extern GdkColor YELLOW;
+extern GdkColor BLACK;
 
 
 /*
@@ -110,6 +107,7 @@ typedef enum
     SPEEX_FILE,      // Speech audio files        : .spx
     OFR_FILE,        // OptimFROG (lossless)      : .ofr .ofs
     WAVPACK_FILE,    // Wavpack (lossless)        : .wv
+    OPUS_FILE, /* Ogg Opus File: .opus */
     UNKNOWN_FILE
 } ET_File_Type;
 
@@ -125,6 +123,7 @@ typedef enum
     FLAC_TAG,
     MP4_TAG,
     WAVPACK_TAG,
+    OPUS_TAG,
     UNKNOWN_TAG
 } ET_Tag_Type;
 
@@ -217,7 +216,7 @@ typedef struct _ET_File_Description ET_File_Description;
 struct _ET_File_Description
 {
     ET_File_Type FileType;    /* Type of file (ex: MP3) */
-    gchar       *Extension;   /* Extension (ex: ".mp3") */
+    const gchar *Extension; /* Extension (ex: ".mp3") */
     ET_Tag_Type  TagType;     /* Type of tag (ex: ID3) */
 };
 
@@ -225,43 +224,10 @@ struct _ET_File_Description
 /*
  * Description of supported files
  */
-static const ET_File_Description ETFileDescription[] = 
-{
-#ifdef ENABLE_MP3
-    {MP3_FILE,     ".mp3",  ID3_TAG},
-    {MP2_FILE,     ".mp2",  ID3_TAG},
-#endif
-#ifdef ENABLE_OGG
-    {OGG_FILE,     ".ogg",  OGG_TAG},
-    {OGG_FILE,     ".oga",  OGG_TAG},
-#endif
-#ifdef ENABLE_SPEEX
-    {SPEEX_FILE,   ".spx",  OGG_TAG},  // Implemented by Pierre Dumuid
-#endif
-#ifdef ENABLE_FLAC
-    {FLAC_FILE,    ".flac", FLAC_TAG},
-    {FLAC_FILE,    ".fla",  FLAC_TAG},
-#endif
-    {MPC_FILE,     ".mpc",  APE_TAG},  // Implemented by Artur Polaczynski
-    {MPC_FILE,     ".mp+",  APE_TAG},  // Implemented by Artur Polaczynski
-    {MPC_FILE,     ".mpp",  APE_TAG},  // Implemented by Artur Polaczynski
-    {MAC_FILE,     ".ape",  APE_TAG},  // Implemented by Artur Polaczynski
-    {MAC_FILE,     ".mac",  APE_TAG},  // Implemented by Artur Polaczynski
-    {OFR_FILE,     ".ofr",  APE_TAG},
-    {OFR_FILE,     ".ofs",  APE_TAG},
-#ifdef ENABLE_MP4
-    {MP4_FILE,     ".mp4",  MP4_TAG},  // Implemented by Michael Ihde
-    {MP4_FILE,     ".m4a",  MP4_TAG},  // Implemented by Michael Ihde
-    {MP4_FILE,     ".m4p",  MP4_TAG},  // Implemented by Michael Ihde
-#endif
-#ifdef ENABLE_WAVPACK
-    {WAVPACK_FILE, ".wv",   WAVPACK_TAG}, // Implemented by Maarten Maathuis
-#endif
-    {UNKNOWN_FILE, "",      UNKNOWN_TAG}    /* This item must be placed to the end! */
-};
+extern const ET_File_Description ETFileDescription[];
 
 /* Calculate the last index of the previous tab */
-#define ET_FILE_DESCRIPTION_SIZE ( sizeof(ETFileDescription)/sizeof(ETFileDescription[0]) - 1 )
+extern const gsize ET_FILE_DESCRIPTION_SIZE;
 
 
 /*
@@ -332,7 +298,7 @@ struct _ET_Core
     GList *ETHistoryFileList;           // History list of files changes for undo/redo actions
 };
 
-ET_Core *ETCore;    // Main pointer to structure needed by EasyTAG
+extern ET_Core *ETCore; /* Main pointer to structure needed by EasyTAG. */
 
 
 
@@ -446,5 +412,6 @@ gint ET_Comp_Func_Sort_File_By_Descending_File_Bitrate    (ET_File *ETFile1, ET_
 gint ET_Comp_Func_Sort_File_By_Ascending_File_Samplerate  (ET_File *ETFile1, ET_File *ETFile2);
 gint ET_Comp_Func_Sort_File_By_Descending_File_Samplerate (ET_File *ETFile1, ET_File *ETFile2);
 
+G_END_DECLS
 
 #endif /* __ET_CORE_H__ */
