@@ -24,6 +24,11 @@
 
 
 #include <glib.h>
+
+#include "config.h"
+
+#ifdef ENABLE_OGG
+
 #include "vcedit.h"
 #include "et_core.h"
 
@@ -33,9 +38,10 @@
 gboolean ogg_tag_read_file_tag (gchar *filename, File_Tag *FileTag,
                                 GError **error);
 gboolean ogg_tag_write_file_tag (ET_File *ETFile, GError **error);
-void
-et_add_file_tags_from_vorbis_comments (vorbis_comment *vc, File_Tag *FileTag,
-                                       const gchar *filename_utf8);
-void
-et_add_vorbis_comments_from_file_tags (vorbis_comment *vc, File_Tag *FileTag);
+
+void et_add_file_tags_from_vorbis_comments (vorbis_comment *vc, File_Tag *FileTag, const gchar *filename_utf8);
+void et_add_vorbis_comments_from_file_tags (vorbis_comment *vc, File_Tag *FileTag);
+
+#endif /* ENABLE_OGG */
+
 #endif /* __OGG_TAG_H__ */
